==> fluxbox_0.9.14.orig.tar.gz: fluxbox-0.9.14.orig/nls/lv_LV/Translation.m <==
$ codeset=ISO-8859-13

$set 1 #Align

1 Apak Centr
2 Apak pa Kreisi
3 Apak pa Labi
4 Horizontls
6 Pa Kreisi Apak
7 Pa Kreisi Centr
8 Pa Kreisi Aug
11 Pa Labi Apak
12 Pa Labi Centr
13 Pa Labi Aug
14 Aug Centr
15 Aug pa Kreisi
16 Aug pa Labi
17 Vertikls

$set 2 #BaseDisplay


$set 3 #Common

2 Auto paslpt

$set 4 #Configmenu

2 Auto Pacelana
4 Klikis, lai Fokustu
7 Fokust Logu pie Darba vietas maias
8 Fokusans Modelis
9 Fokust Jaunos Logus
10 Pilna Maksimizcija
11 Attla Tonana
12 Necaurredzama Loga Prvietoana
13 Pusnevga Fokusana
14 Nevga Fokusana
15 Prvilkana uz Darba vietu

$set 5 #Ewmh


$set 6 #FbTkError


$set 7 #Fluxbox


$set 8 #Gnome


$set 9 #Keys


$set 10 #Menu

3 Iziet
4 Ikonas
7 Novietoana
9 Restartt
10 xterm

$set 11 #Remember


$set 12 #Screen

2 P: %4d x A: %4d
5 X: %4d x Y: %4d
6 0: 0000 x 0: 0000

$set 13 #Slit

4 luma Virziens
7 luma Novietojums
8 lums

$set 14 #Toolbar

1 Redit pareizjs darba vietas nosaukumu
11 Rkjosla

$set 15 #Window

1 Nenosaukts

$set 16 #Windowmenu

1 Aizvrt
2 Ikonifict
4 Pazemint
5 Maksimizt
6 Pacelt
7 Stt Uz ...
8 not
9 Stit

$set 17 #Workspace

1 Darba vieta %d
2 Darba vietas
3 Jauna Darba vieta
4 Noemt Pdjo

$set 18 #fbsetroot

1 %s: kda: jnosaka viens no: -solid, -mod, -gradient\n
3 %s 2.0: (c) 1997-2000 Brad Hughes\n\n\
-display <virkne>        displeja savienojums\n\
-mod <x> <y>             modua raksts\n\
-foreground, -fg <krsa> modua priekplna krsa\n\
-background, -bg <krsa> modua fona krsa\n\n\
-gradient <tekstra>     gradienta tekstra\n\
-from <krsa>            prejas skuma krsa\n\
-to <krsa>              prejas beigu krsa\n\n\
-solid <krsa>           viendabga krsa\n\n\
-help                    pardt o paldzbu un iziet\n

$set 19 #main

1 kda: '-display' nepiecieams arguments\n
11 kda: '-rc' nepiecieams arguments\n
12 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <virkne>\t\tlietot displeja savienojumu.\n\
-rc <virkne>\t\t\tlietot citu resersu failu.\n\
-version\t\t\tpardt versiju un iziet.\n\
-info\t\t\t\tdisplay some useful information.\n\
-log <filename>\t\t\tlog output to file.\n\
-help\t\t\t\tpardt o paldzbas tekstu un iziet.\n\n

==> fluxbox_1.3.5.orig.tar.gz: fluxbox-1.3.5/nls/lv_LV/Translation.m <==
$ codeset=ISO-8859-13

$set 1 #Align

1 Apak Centr
2 Apak pa Kreisi
3 Apak pa Labi
4 Horizontls
6 Pa Kreisi Apak
7 Pa Kreisi Centr
8 Pa Kreisi Aug
11 Pa Labi Apak
12 Pa Labi Centr
13 Pa Labi Aug
14 Aug Centr
15 Aug pa Kreisi
16 Aug pa Labi
17 Vertikls

$set 2 #BaseDisplay


$set 3 #Common

2 Auto paslpt

$set 4 #Configmenu

2 Auto Pacelana
4 Klikis, lai Fokustu
7 Fokust Logu pie Darba vietas maias
8 Fokusans Modelis
9 Fokust Jaunos Logus
10 Pilna Maksimizcija
11 Attla Tonana
12 Necaurredzama Loga Prvietoana
13 Pusnevga Fokusana
14 Nevga Fokusana
15 Prvilkana uz Darba vietu

$set 5 #Ewmh


$set 6 #FbTkError


$set 7 #Fluxbox


$set 8 #Gnome


$set 9 #Keys


$set 10 #Menu

3 Iziet
4 Ikonas
7 Novietoana
9 Restartt

$set 11 #Remember


$set 12 #Screen

2 P: %4d x A: %4d
4 P: %04d x A: %04d

$set 13 #Slit

4 luma Virziens
7 luma Novietojums
8 lums

$set 14 #Toolbar

1 Redit pareizjs darba vietas nosaukumu
11 Rkjosla

$set 15 #Window

1 Nenosaukts

$set 16 #Windowmenu

1 Aizvrt
2 Ikonifict
4 Pazemint
5 Maksimizt
6 Pacelt
7 Stt Uz ...
8 not
9 Stit

$set 17 #Workspace

1 Darba vieta %d
2 Darba vietas
3 Jauna Darba vieta
4 Noemt Pdjo

$set 18 #fbsetroot

1 kda: jnosaka viens no: -solid, -mod, -gradient\n
3 -display <virkne>        displeja savienojums\n\
-mod <x> <y>             modua raksts\n\
-foreground, -fg <krsa> modua priekplna krsa\n\
-background, -bg <krsa> modua fona krsa\n\n\
-gradient <tekstra>     gradienta tekstra\n\
-from <krsa>            prejas skuma krsa\n\
-to <krsa>              prejas beigu krsa\n\n\
-solid <krsa>           viendabga krsa\n\n\
-help                    pardt o paldzbu un iziet\n

$set 19 #main

1 kda: '-display' nepiecieams arguments
11 kda: '-rc' nepiecieams arguments
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <virkne>\t\tlietot displeja savienojumu.\n\
-rc <virkne>\t\t\tlietot citu resersu failu.\n\
-version\t\t\tpardt versiju un iziet.\n\
-info\t\t\t\tdisplay some useful information.\n\
-log <filename>\t\t\tlog output to file.\n\
-help\t\t\t\tpardt o paldzbas tekstu un iziet.\n\n
